move export functionality to libuci
[project/uci.git] / uci.h
diff --git a/uci.h b/uci.h
index c5594d8..a34a36b 100644 (file)
--- a/uci.h
+++ b/uci.h
@@ -62,6 +62,25 @@ extern void uci_free(struct uci_context *ctx);
 extern void uci_perror(struct uci_context *ctx, const char *str);
 
 /**
+ * uci_import: Import uci config data from a stream
+ * @ctx: uci context
+ * @stream: file stream to import from
+ * @name: (optional) assume the config has the given name
+ * @cfg: (optional) store the last parsed config package in this variable
+ *
+ * the name parameter is for config files that don't explicitly use the 'package <...>' keyword
+ */
+extern int uci_import(struct uci_context *ctx, FILE *stream, const char *name, struct uci_config **cfg);
+
+/**
+ * uci_export: Export one or all uci config packages
+ * @ctx: uci context
+ * @stream: output stream
+ * @cfg: (optional) uci config package to export
+ */
+extern int uci_export(struct uci_context *ctx, FILE *stream, struct uci_config *cfg);
+
+/**
  * uci_load: Parse an uci config file and store it in the uci context
  *
  * @ctx: uci context
@@ -95,18 +114,23 @@ extern char **uci_list_configs();
 
 struct uci_context
 {
+       /* list of config packages */
        struct uci_list root;
 
/* for error handling only */
        struct uci_parse_context *pctx;
 
        /* private: */
        int errno;
        jmp_buf trap;
+       char *buf;
+       int bufsz;
 };
 
 struct uci_parse_context
 {
+       /* error context */
+       const char *reason;
        int line;
        int byte;
 
@@ -114,8 +138,8 @@ struct uci_parse_context
        struct uci_config *cfg;
        struct uci_section *section;
        FILE *file;
+       const char *name;
        char *buf;
-       char *reason;
        int bufsz;
 };
 
@@ -151,10 +175,28 @@ struct uci_option
 #define offsetof(TYPE, MEMBER) ((size_t) &((TYPE *)0)->MEMBER)
 #endif
 
+/* returns true if a list is empty */
 #define uci_list_empty(list) ((list)->next == (list))
+
+/**
+ * uci_list_entry: casts an uci_list pointer to the containing struct.
+ * @_type: config, section or option
+ * @_ptr: pointer to the uci_list struct
+ */
 #define uci_list_entry(_type, _ptr) \
        ((struct uci_ ## _type *) ((char *)(_ptr) - offsetof(struct uci_ ## _type,list)))
 
+/**
+ * uci_foreach_entry: loop through a list of configs, sections or options
+ * @_type: see uci_list_entry
+ * @_list: pointer to the uci_list struct
+ * @_ptr: iteration variable
+ *
+ * use like a for loop, e.g:
+ *   uci_foreach(section, &list, p) {
+ *     ...
+ *   }
+ */
 #define uci_foreach_entry(_type, _list, _ptr)          \
        for(_ptr = uci_list_entry(_type, (_list)->next);        \
                &_ptr->list != (_list);                 \
@@ -95,18 +114,23 @@ extern char **uci_list_configs();
        struct uci_list root;
 
-       /* for error handling only */
+       /* parser context, use for error handling only */
        struct uci_parse_context *pctx;
 